@@ -1,11 +1,11 @@
 /* Public API for GNU gettext PO files.
-   Copyright (C) 2003-2006 Free Software Foundation, Inc.
+   Copyright (C) 2003-2010 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2003.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -40,8 +39,8 @@
 #include "xerror.h"
 #include "po-error.h"
 #include "po-xerror.h"
-#include "vasprintf.h"
 #include "format.h"
+#include "xvasprintf.h"
 #include "msgl-check.h"
 #include "gettext.h"
 
@@ -80,7 +79,7 @@ po_file_create (void)
 {
   po_file_t file;
 
-  file = (struct po_file *) xmalloc (sizeof (struct po_file));
+  file = XMALLOC (struct po_file);
   file->mdlp = msgdomain_list_alloc (false);
   file->real_filename = _("<unnamed>");
   file->logical_filename = file->real_filename;
@@ -107,7 +106,7 @@ po_file_read (const char *filename, po_xerror_handler_t handler)
     {
       fp = fopen (filename, "r");
       if (fp == NULL)
-	return NULL;
+        return NULL;
     }
 
   /* Establish error handler around read_catalog_stream().  */
@@ -119,11 +118,11 @@ po_file_read (const char *filename, po_xerror_handler_t handler)
     handler->xerror2;
   gram_max_allowed_errors = UINT_MAX;
 
-  file = (struct po_file *) xmalloc (sizeof (struct po_file));
+  file = XMALLOC (struct po_file);
   file->real_filename = filename;
   file->logical_filename = filename;
   file->mdlp = read_catalog_stream (fp, file->real_filename,
-				    file->logical_filename, &input_format_po);
+                                    file->logical_filename, &input_format_po);
   file->domains = NULL;
 
   /* Restore error handler.  */
@@ -137,6 +136,9 @@ po_file_read (const char *filename, po_xerror_handler_t handler)
 }
 #undef po_file_read
 
+#ifdef __cplusplus
+extern "C" po_file_t po_file_read_v2 (const char *filename, po_error_handler_t handler);
+#endif
 po_file_t
 po_file_read_v2 (const char *filename, po_error_handler_t handler)
 {
@@ -152,7 +154,7 @@ po_file_read_v2 (const char *filename, po_error_handler_t handler)
     {
       fp = fopen (filename, "r");
       if (fp == NULL)
-	return NULL;
+        return NULL;
     }
 
   /* Establish error handler around read_catalog_stream().  */
@@ -162,11 +164,11 @@ po_file_read_v2 (const char *filename, po_error_handler_t handler)
   po_multiline_error   = handler->multiline_error;
   gram_max_allowed_errors = UINT_MAX;
 
-  file = (struct po_file *) xmalloc (sizeof (struct po_file));
+  file = XMALLOC (struct po_file);
   file->real_filename = filename;
   file->logical_filename = filename;
   file->mdlp = read_catalog_stream (fp, file->real_filename,
-				    file->logical_filename, &input_format_po);
+                                    file->logical_filename, &input_format_po);
   file->domains = NULL;
 
   /* Restore error handler.  */
@@ -182,6 +184,9 @@ po_file_read_v2 (const char *filename, po_error_handler_t handler)
 }
 
 /* Older version for binary backward compatibility.  */
+#ifdef __cplusplus
+extern "C" po_file_t po_file_read (const char *filename);
+#endif
 po_file_t
 po_file_read (const char *filename)
 {
@@ -197,14 +202,14 @@ po_file_read (const char *filename)
     {
       fp = fopen (filename, "r");
       if (fp == NULL)
-	return NULL;
+        return NULL;
     }
 
-  file = (struct po_file *) xmalloc (sizeof (struct po_file));
+  file = XMALLOC (struct po_file);
   file->real_filename = filename;
   file->logical_filename = filename;
   file->mdlp = read_catalog_stream (fp, file->real_filename,
-				    file->logical_filename, &input_format_po);
+                                    file->logical_filename, &input_format_po);
   file->domains = NULL;
 
   if (fp != stdin)
@@ -238,6 +243,9 @@ po_file_write (po_file_t file, const char *filename, po_xerror_handler_t handler
 #undef po_file_write
 
 /* Older version for binary backward compatibility.  */
+#ifdef __cplusplus
+extern "C" po_file_t po_file_write (po_file_t file, const char *filename, po_error_handler_t handler);
+#endif
 po_file_t
 po_file_write (po_file_t file, const char *filename, po_error_handler_t handler)
 {
@@ -279,12 +287,11 @@ po_file_domains (po_file_t file)
   if (file->domains == NULL)
     {
       size_t n = file->mdlp->nitems;
-      const char **domains =
-	(const char **) xmalloc ((n + 1) * sizeof (const char *));
+      const char **domains = XNMALLOC (n + 1, const char *);
       size_t j;
 
       for (j = 0; j < n; j++)
-	domains[j] = file->mdlp->item[j]->domain;
+        domains[j] = file->mdlp->item[j]->domain;
       domains[n] = NULL;
 
       file->domains = domains;
@@ -310,14 +317,14 @@ po_file_domain_header (po_file_t file, const char *domain)
   if (mlp != NULL)
     for (j = 0; j < mlp->nitems; j++)
       if (is_header (mlp->item[j]) && !mlp->item[j]->obsolete)
-	{
-	  const char *header = mlp->item[j]->msgstr;
+        {
+          const char *header = mlp->item[j]->msgstr;
 
-	  if (header != NULL)
-	    return xstrdup (header);
-	  else
-	    return NULL;
-	}
+          if (header != NULL)
+            return xstrdup (header);
+          else
+            return NULL;
+        }
   return NULL;
 }
 
@@ -334,30 +341,31 @@ po_header_field (const char *header, const char *field)
 
   for (line = header;;)
     {
-      if (strncmp (line, field, field_len) == 0
-	  && line[field_len] == ':' && line[field_len + 1] == ' ')
-	{
-	  const char *value_start;
-	  const char *value_end;
-	  char *value;
+      if (strncmp (line, field, field_len) == 0 && line[field_len] == ':')
+        {
+          const char *value_start;
+          const char *value_end;
+          char *value;
 
-	  value_start = line + field_len + 2;
-	  value_end = strchr (value_start, '\n');
-	  if (value_end == NULL)
-	    value_end = value_start + strlen (value_start);
+          value_start = line + field_len + 1;
+          if (*value_start == ' ')
+            value_start++;
+          value_end = strchr (value_start, '\n');
+          if (value_end == NULL)
+            value_end = value_start + strlen (value_start);
 
-	  value = (char *) xmalloc (value_end - value_start + 1);
-	  memcpy (value, value_start, value_end - value_start);
-	  value[value_end - value_start] = '\0';
+          value = XNMALLOC (value_end - value_start + 1, char);
+          memcpy (value, value_start, value_end - value_start);
+          value[value_end - value_start] = '\0';
 
-	  return value;
-	}
+          return value;
+        }
 
       line = strchr (line, '\n');
       if (line != NULL)
-	line++;
+        line++;
       else
-	break;
+        break;
     }
 
   return NULL;
@@ -380,42 +388,43 @@ po_header_set_field (const char *header, const char *field, const char *value)
 
     for (line = header;;)
       {
-	if (strncmp (line, field, field_len) == 0
-	    && line[field_len] == ':' && line[field_len + 1] == ' ')
-	  {
-	    const char *oldvalue_start;
-	    const char *oldvalue_end;
-	    size_t oldvalue_len;
-	    size_t header_part1_len;
-	    size_t header_part3_len;
-	    size_t result_len;
-	    char *result;
+        if (strncmp (line, field, field_len) == 0 && line[field_len] == ':')
+          {
+            const char *oldvalue_start;
+            const char *oldvalue_end;
+            size_t oldvalue_len;
+            size_t header_part1_len;
+            size_t header_part3_len;
+            size_t result_len;
+            char *result;
 
-	    oldvalue_start = line + field_len + 2;
-	    oldvalue_end = strchr (oldvalue_start, '\n');
-	    if (oldvalue_end == NULL)
-	      oldvalue_end = oldvalue_start + strlen (oldvalue_start);
-	    oldvalue_len = oldvalue_end - oldvalue_start;
+            oldvalue_start = line + field_len + 1;
+            if (*oldvalue_start == ' ')
+              oldvalue_start++;
+            oldvalue_end = strchr (oldvalue_start, '\n');
+            if (oldvalue_end == NULL)
+              oldvalue_end = oldvalue_start + strlen (oldvalue_start);
+            oldvalue_len = oldvalue_end - oldvalue_start;
 
-	    header_part1_len = oldvalue_start - header;
-	    header_part3_len = header + header_len - oldvalue_end;
-	    result_len = header_part1_len + value_len + header_part3_len;
-		    /* = header_len - oldvalue_len + value_len */
-	    result = (char *) xmalloc (result_len + 1);
-	    memcpy (result, header, header_part1_len);
-	    memcpy (result + header_part1_len, value, value_len);
-	    memcpy (result + header_part1_len + value_len, oldvalue_end,
-		    header_part3_len);
-	    *(result + result_len) = '\0';
+            header_part1_len = oldvalue_start - header;
+            header_part3_len = header + header_len - oldvalue_end;
+            result_len = header_part1_len + value_len + header_part3_len;
+                    /* = header_len - oldvalue_len + value_len */
+            result = XNMALLOC (result_len + 1, char);
+            memcpy (result, header, header_part1_len);
+            memcpy (result + header_part1_len, value, value_len);
+            memcpy (result + header_part1_len + value_len, oldvalue_end,
+                    header_part3_len);
+            *(result + result_len) = '\0';
 
-	    return result;
-	  }
+            return result;
+          }
 
-	line = strchr (line, '\n');
-	if (line != NULL)
-	  line++;
-	else
-	  break;
+        line = strchr (line, '\n');
+        if (line != NULL)
+          line++;
+        else
+          break;
       }
   }
   {
@@ -425,7 +434,7 @@ po_header_set_field (const char *header, const char *field, const char *value)
 
     newline = (header_len > 0 && header[header_len - 1] != '\n' ? 1 : 0);
     result_len = header_len + newline + field_len + 2 + value_len + 1;
-    result = (char *) xmalloc (result_len + 1);
+    result = XNMALLOC (result_len + 1, char);
     memcpy (result, header, header_len);
     if (newline)
       *(result + header_len) = '\n';
@@ -452,9 +461,7 @@ po_message_iterator (po_file_t file, const char *domain)
   if (domain == NULL)
     domain = MESSAGE_DOMAIN_DEFAULT;
 
-  iterator =
-    (struct po_message_iterator *)
-    xmalloc (sizeof (struct po_message_iterator));
+  iterator = XMALLOC (struct po_message_iterator);
   iterator->file = file;
   iterator->domain = xstrdup (domain);
   iterator->mlp = msgdomain_list_sublist (file->mdlp, domain, false);
@@ -515,7 +522,7 @@ po_message_create (void)
 {
   lex_pos_ty pos = { NULL, 0 };
 
-  return (po_message_t) message_alloc (NULL, NULL, NULL, NULL, 0, &pos);
+  return (po_message_t) message_alloc (NULL, NULL, NULL, xstrdup (""), 1, &pos);
 }
 
 
@@ -543,7 +550,7 @@ po_message_set_msgctxt (po_message_t message, const char *msgctxt)
 
       mp->msgctxt = (msgctxt != NULL ? xstrdup (msgctxt) : NULL);
       if (old_msgctxt != NULL)
-	free (old_msgctxt);
+        free (old_msgctxt);
     }
 }
 
@@ -572,7 +579,7 @@ po_message_set_msgid (po_message_t message, const char *msgid)
 
       mp->msgid = xstrdup (msgid);
       if (old_msgid != NULL)
-	free (old_msgid);
+        free (old_msgid);
     }
 }
 
@@ -603,7 +610,7 @@ po_message_set_msgid_plural (po_message_t message, const char *msgid_plural)
 
       mp->msgid_plural = (msgid_plural != NULL ? xstrdup (msgid_plural) : NULL);
       if (old_msgid_plural != NULL)
-	free (old_msgid_plural);
+        free (old_msgid_plural);
     }
 }
 
@@ -635,7 +642,7 @@ po_message_set_msgstr (po_message_t message, const char *msgstr)
       mp->msgstr = xstrdup (msgstr);
       mp->msgstr_len = strlen (mp->msgstr) + 1;
       if (old_msgstr != NULL)
-	free (old_msgstr);
+        free (old_msgstr);
     }
 }
 
@@ -654,12 +661,12 @@ po_message_msgstr_plural (po_message_t message, int index)
       const char *p_end = mp->msgstr + mp->msgstr_len;
 
       for (p = mp->msgstr; ; p += strlen (p) + 1, index--)
-	{
-	  if (p >= p_end)
-	    return NULL;
-	  if (index == 0)
-	    break;
-	}
+        {
+          if (p >= p_end)
+            return NULL;
+          if (index == 0)
+            break;
+        }
       return p;
     }
   else
@@ -682,66 +689,66 @@ po_message_set_msgstr_plural (po_message_t message, int index, const char *msgst
       char *copied_msgstr;
 
       /* Special care must be taken of the case that msgstr points into the
-	 mp->msgstr string list, because mp->msgstr may be relocated before we
-	 are done with msgstr.  */
+         mp->msgstr string list, because mp->msgstr may be relocated before we
+         are done with msgstr.  */
       if (msgstr >= p && msgstr < p_end)
-	msgstr = copied_msgstr = xstrdup (msgstr);
+        msgstr = copied_msgstr = xstrdup (msgstr);
       else
-	copied_msgstr = NULL;
+        copied_msgstr = NULL;
 
       for (; ; p += strlen (p) + 1, index--)
-	{
-	  if (p >= p_end)
-	    {
-	      /* Append at the end.  */
-	      if (msgstr != NULL)
-		{
-		  size_t new_msgstr_len = mp->msgstr_len + index + strlen (msgstr) + 1;
+        {
+          if (p >= p_end)
+            {
+              /* Append at the end.  */
+              if (msgstr != NULL)
+                {
+                  size_t new_msgstr_len = mp->msgstr_len + index + strlen (msgstr) + 1;
 
-		  mp->msgstr =
-		    (char *) xrealloc ((char *) mp->msgstr, new_msgstr_len);
-		  p = (char *) mp->msgstr + mp->msgstr_len;
-		  for (; index > 0; index--)
-		    *p++ = '\0';
-		  memcpy (p, msgstr, strlen (msgstr) + 1);
-		  mp->msgstr_len = new_msgstr_len;
-		}
-	      if (copied_msgstr != NULL)
-		free (copied_msgstr);
-	      return;
-	    }
-	  if (index == 0)
-	    break;
-	}
+                  mp->msgstr =
+                    (char *) xrealloc ((char *) mp->msgstr, new_msgstr_len);
+                  p = (char *) mp->msgstr + mp->msgstr_len;
+                  for (; index > 0; index--)
+                    *p++ = '\0';
+                  memcpy (p, msgstr, strlen (msgstr) + 1);
+                  mp->msgstr_len = new_msgstr_len;
+                }
+              if (copied_msgstr != NULL)
+                free (copied_msgstr);
+              return;
+            }
+          if (index == 0)
+            break;
+        }
       if (msgstr == NULL)
-	{
-	  if (p + strlen (p) + 1 >= p_end)
-	    {
-	      /* Remove the string that starts at p.  */
-	      mp->msgstr_len = p - mp->msgstr;
-	      return;
-	    }
-	  /* It is not possible to remove an element of the string list
-	     except the last one.  So just replace it with the empty string.
-	     That's the best we can do here.  */
-	  msgstr = "";
-	}
+        {
+          if (p + strlen (p) + 1 >= p_end)
+            {
+              /* Remove the string that starts at p.  */
+              mp->msgstr_len = p - mp->msgstr;
+              return;
+            }
+          /* It is not possible to remove an element of the string list
+             except the last one.  So just replace it with the empty string.
+             That's the best we can do here.  */
+          msgstr = "";
+        }
       {
-	/* Replace the string that starts at p.  */
-	size_t i1 = p - mp->msgstr;
-	size_t i2before = i1 + strlen (p);
-	size_t i2after = i1 + strlen (msgstr);
-	size_t new_msgstr_len = mp->msgstr_len - i2before + i2after;
+        /* Replace the string that starts at p.  */
+        size_t i1 = p - mp->msgstr;
+        size_t i2before = i1 + strlen (p);
+        size_t i2after = i1 + strlen (msgstr);
+        size_t new_msgstr_len = mp->msgstr_len - i2before + i2after;
 
-	if (i2after > i2before)
-	  mp->msgstr = (char *) xrealloc ((char *) mp->msgstr, new_msgstr_len);
-	memmove ((char *) mp->msgstr + i2after, mp->msgstr + i2before,
-		 mp->msgstr_len - i2before);
-	memcpy ((char *) mp->msgstr + i1, msgstr, i2after - i1);
-	mp->msgstr_len = new_msgstr_len;
+        if (i2after > i2before)
+          mp->msgstr = (char *) xrealloc ((char *) mp->msgstr, new_msgstr_len);
+        memmove ((char *) mp->msgstr + i2after, mp->msgstr + i2before,
+                 mp->msgstr_len - i2before);
+        memcpy ((char *) mp->msgstr + i1, msgstr, i2after - i1);
+        mp->msgstr_len = new_msgstr_len;
       }
       if (copied_msgstr != NULL)
-	free (copied_msgstr);
+        free (copied_msgstr);
     }
 }
 
@@ -757,7 +764,7 @@ po_message_comments (po_message_t message)
   if (mp->comment == NULL || mp->comment->nitems == 0)
     return "";
   else
-    return string_list_join (mp->comment, '\n', '\n', true);
+    return string_list_join (mp->comment, "\n", '\n', true);
 }
 
 
@@ -777,19 +784,19 @@ po_message_set_comments (po_message_t message, const char *comments)
     rest = copy;
     while (*rest != '\0')
       {
-	char *newline = strchr (rest, '\n');
+        char *newline = strchr (rest, '\n');
 
-	if (newline != NULL)
-	  {
-	    *newline = '\0';
-	    string_list_append (slp, rest);
-	    rest = newline + 1;
-	  }
-	else
-	  {
-	    string_list_append (slp, rest);
-	    break;
-	  }
+        if (newline != NULL)
+          {
+            *newline = '\0';
+            string_list_append (slp, rest);
+            rest = newline + 1;
+          }
+        else
+          {
+            string_list_append (slp, rest);
+            break;
+          }
       }
     free (copy);
   }
@@ -812,7 +819,7 @@ po_message_extracted_comments (po_message_t message)
   if (mp->comment_dot == NULL || mp->comment_dot->nitems == 0)
     return "";
   else
-    return string_list_join (mp->comment_dot, '\n', '\n', true);
+    return string_list_join (mp->comment_dot, "\n", '\n', true);
 }
 
 
@@ -832,19 +839,19 @@ po_message_set_extracted_comments (po_message_t message, const char *comments)
     rest = copy;
     while (*rest != '\0')
       {
-	char *newline = strchr (rest, '\n');
+        char *newline = strchr (rest, '\n');
 
-	if (newline != NULL)
-	  {
-	    *newline = '\0';
-	    string_list_append (slp, rest);
-	    rest = newline + 1;
-	  }
-	else
-	  {
-	    string_list_append (slp, rest);
-	    break;
-	  }
+        if (newline != NULL)
+          {
+            *newline = '\0';
+            string_list_append (slp, rest);
+            rest = newline + 1;
+          }
+        else
+          {
+            string_list_append (slp, rest);
+            break;
+          }
       }
     free (copy);
   }
@@ -886,12 +893,12 @@ po_message_remove_filepos (po_message_t message, int i)
       size_t n = mp->filepos_count;
 
       if (j < n)
-	{
-	  mp->filepos_count = n = n - 1;
-	  free ((char *) mp->filepos[j].file_name);
-	  for (; j < n; j++)
-	    mp->filepos[j] = mp->filepos[j + 1];
-	}
+        {
+          mp->filepos_count = n = n - 1;
+          free ((char *) mp->filepos[j].file_name);
+          for (; j < n; j++)
+            mp->filepos[j] = mp->filepos[j + 1];
+        }
     }
 }
 
@@ -935,7 +942,7 @@ po_message_set_prev_msgctxt (po_message_t message, const char *prev_msgctxt)
 
       mp->prev_msgctxt = (prev_msgctxt != NULL ? xstrdup (prev_msgctxt) : NULL);
       if (old_prev_msgctxt != NULL)
-	free (old_prev_msgctxt);
+        free (old_prev_msgctxt);
     }
 }
 
@@ -966,7 +973,7 @@ po_message_set_prev_msgid (po_message_t message, const char *prev_msgid)
 
       mp->prev_msgid = (prev_msgid != NULL ? xstrdup (prev_msgid) : NULL);
       if (old_prev_msgid != NULL)
-	free (old_prev_msgid);
+        free (old_prev_msgid);
     }
 }
 
@@ -996,9 +1003,9 @@ po_message_set_prev_msgid_plural (po_message_t message, const char *prev_msgid_p
       char *old_prev_msgid_plural = (char *) mp->prev_msgid_plural;
 
       mp->prev_msgid_plural =
-	(prev_msgid_plural != NULL ? xstrdup (prev_msgid_plural) : NULL);
+        (prev_msgid_plural != NULL ? xstrdup (prev_msgid_plural) : NULL);
       if (old_prev_msgid_plural != NULL)
-	free (old_prev_msgid_plural);
+        free (old_prev_msgid_plural);
     }
 }
 
@@ -1060,9 +1067,9 @@ po_message_is_format (po_message_t message, const char *format_type)
   if (len >= 7 && memcmp (format_type + len - 7, "-format", 7) == 0)
     for (i = 0; i < NFORMATS; i++)
       if (strlen (format_language[i]) == len - 7
-	  && memcmp (format_language[i], format_type, len - 7) == 0)
-	/* The given format_type corresponds to (enum format_type) i.  */
-	return (possible_format_p (mp->is_format[i]) ? 1 : 0);
+          && memcmp (format_language[i], format_type, len - 7) == 0)
+        /* The given format_type corresponds to (enum format_type) i.  */
+        return (possible_format_p (mp->is_format[i]) ? 1 : 0);
   return 0;
 }
 
@@ -1079,9 +1086,51 @@ po_message_set_format (po_message_t message, const char *format_type, /*bool*/in
   if (len >= 7 && memcmp (format_type + len - 7, "-format", 7) == 0)
     for (i = 0; i < NFORMATS; i++)
       if (strlen (format_language[i]) == len - 7
-	  && memcmp (format_language[i], format_type, len - 7) == 0)
-	/* The given format_type corresponds to (enum format_type) i.  */
-	mp->is_format[i] = (value ? yes : no);
+          && memcmp (format_language[i], format_type, len - 7) == 0)
+        /* The given format_type corresponds to (enum format_type) i.  */
+        mp->is_format[i] = (value ? yes : no);
+}
+
+
+/* If a numeric range of a message is set, return true and store the minimum
+   and maximum value in *MINP and *MAXP.  */
+
+int
+po_message_is_range (po_message_t message, int *minp, int *maxp)
+{
+  message_ty *mp = (message_ty *) message;
+
+  if (has_range_p (mp->range))
+    {
+      *minp = mp->range.min;
+      *maxp = mp->range.max;
+      return 1;
+    }
+  else
+    return 0;
+}
+
+
+/* Change the numeric range of a message.  MIN and MAX must be non-negative,
+   with MIN < MAX.  Use MIN = MAX = -1 to remove the numeric range of a
+   message.  */
+
+void
+po_message_set_range (po_message_t message, int min, int max)
+{
+  message_ty *mp = (message_ty *) message;
+
+  if (min >= 0 && max >= min)
+    {
+      mp->range.min = min;
+      mp->range.max = max;
+    }
+  else if (min < 0 && max < 0)
+    {
+      mp->range.min = -1;
+      mp->range.max = -1;
+    }
+  /* Other values of min and max are invalid.  */
 }
 
 
@@ -1108,6 +1157,45 @@ po_filepos_start_line (po_filepos_t filepos)
 }
 
 
+/* Return a NULL terminated array of the supported format types.  */
+
+const char * const *
+po_format_list (void)
+{
+  static const char * const * whole_list /* = NULL */;
+  if (whole_list == NULL)
+    {
+      const char **list = XNMALLOC (NFORMATS + 1, const char *);
+      size_t i;
+      for (i = 0; i < NFORMATS; i++)
+        list[i] = xasprintf ("%s-format", format_language[i]);
+      list[i] = NULL;
+      whole_list = list;
+    }
+  return whole_list;
+}
+
+
+/* Return the pretty name associated with a format type.
+   For example, for "csharp-format", return "C#".
+   Return NULL if the argument is not a supported format type.  */
+
+const char *
+po_format_pretty_name (const char *format_type)
+{
+  size_t len = strlen (format_type);
+  size_t i;
+
+  if (len >= 7 && memcmp (format_type + len - 7, "-format", 7) == 0)
+    for (i = 0; i < NFORMATS; i++)
+      if (strlen (format_language[i]) == len - 7
+          && memcmp (format_language[i], format_type, len - 7) == 0)
+        /* The given format_type corresponds to (enum format_type) i.  */
+        return format_language_pretty[i];
+  return NULL;
+}
+
+
 /* Test whether an entire file PO file is valid, like msgfmt does it.
    If it is invalid, pass the reasons to the handler.  */
 
@@ -1127,7 +1215,7 @@ po_file_check_all (po_file_t file, po_xerror_handler_t handler)
 
   mdlp = file->mdlp;
   for (k = 0; k < mdlp->nitems; k++)
-    check_message_list (mdlp->item[k]->messages, 1, 1, 1, 0, 0, 0);
+    check_message_list (mdlp->item[k]->messages, 1, 1, 1, 1, 1, 0, 0, 0);
 
   /* Restore error handler.  */
   po_xerror  = textmode_xerror;
@@ -1141,7 +1229,7 @@ po_file_check_all (po_file_t file, po_xerror_handler_t handler)
 
 void
 po_message_check_all (po_message_t message, po_message_iterator_t iterator,
-		      po_xerror_handler_t handler)
+                      po_xerror_handler_t handler)
 {
   message_ty *mp = (message_ty *) message;
 
@@ -1165,14 +1253,14 @@ po_message_check_all (po_message_t message, po_message_iterator_t iterator,
 
       header = NULL;
       mlp =
-	msgdomain_list_sublist (iterator->file->mdlp, iterator->domain, false);
+        msgdomain_list_sublist (iterator->file->mdlp, iterator->domain, false);
       if (mlp != NULL)
-	for (j = 0; j < mlp->nitems; j++)
-	  if (is_header (mlp->item[j]) && !mlp->item[j]->obsolete)
-	    {
-	      header = mlp->item[j];
-	      break;
-	    }
+        for (j = 0; j < mlp->nitems; j++)
+          if (is_header (mlp->item[j]) && !mlp->item[j]->obsolete)
+            {
+              header = mlp->item[j];
+              break;
+            }
     }
 
     {
@@ -1184,11 +1272,11 @@ po_message_check_all (po_message_t message, po_message_iterator_t iterator,
       ml.use_hashtable = false;
 
       if (header != NULL)
-	message_list_append (&ml, header);
+        message_list_append (&ml, header);
       if (mp != header)
-	message_list_append (&ml, mp);
+        message_list_append (&ml, mp);
 
-      check_message_list (&ml, 1, 1, 1, 0, 0, 0);
+      check_message_list (&ml, 1, 1, 1, 1, 1, 0, 0, 0);
     }
   }
 
@@ -1246,6 +1334,9 @@ po_error_logger (const char *format, ...)
 /* Test whether the message translation is a valid format string if the message
    is marked as being a format string.  If it is invalid, pass the reasons to
    the handler.  */
+#ifdef __cplusplus
+extern "C" void po_message_check_format (po_message_t message, po_error_handler_t handler);
+#endif
 void
 po_message_check_format (po_message_t message, po_error_handler_t handler)
 {
@@ -1255,8 +1346,8 @@ po_message_check_format (po_message_t message, po_error_handler_t handler)
   po_error = handler->error;
 
   check_msgid_msgstr_format (mp->msgid, mp->msgid_plural,
-			     mp->msgstr, mp->msgstr_len,
-			     mp->is_format, NULL, po_error_logger);
+                             mp->msgstr, mp->msgstr_len,
+                             mp->is_format, mp->range, NULL, po_error_logger);
 
   /* Restore error handler.  */
   po_error = error;
